@@ -9,28 +9,28 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("2.7.") or
-    raise "ruby lib version (2.7.8) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("3.0.") or
+    raise "ruby lib version (3.0.7) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.7/2.7.0/i386-darwin10.0")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby3.0/3.0.0/i386-darwin10.0")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
-  CONFIG["MAJOR"] = "2"
-  CONFIG["MINOR"] = "7"
-  CONFIG["TEENY"] = "8"
-  CONFIG["PATCHLEVEL"] = "225"
+  CONFIG["MAJOR"] = "3"
+  CONFIG["MINOR"] = "0"
+  CONFIG["TEENY"] = "7"
+  CONFIG["PATCHLEVEL"] = "220"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)2.7"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)2.7"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)3.0"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)3.0"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME).$(RUBY_API_VERSION)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-2.7.pc"
+  CONFIG["ruby_pc"] = "ruby-3.0.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -44,7 +44,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-gmp' '--with-opt-dir=/opt/local' '--program-suffix=2.7' '--with-rubylibprefix=/opt/local/lib/ruby2.7' '--with-openssl-dir=/opt/local/libexec/openssl11' '--without-baseruby' '--with-arch=i386' '--disable-dtrace' 'CC=/opt/local/bin/clang-mp-11' 'CFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -std=c99 -arch i386' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch i386' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -isystem/opt/local/include' 'CXX=/opt/local/bin/clang++-mp-11' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++ -arch i386'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-gmp' '--with-opt-dir=/opt/local' '--program-suffix=3.0' '--with-rubylibprefix=/opt/local/lib/ruby3.0' '--with-openssl-dir=/opt/local/libexec/openssl11' '--without-baseruby' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' '--with-arch=i386' '--disable-dtrace' 'CC=/opt/local/bin/clang-mp-11' 'CXX=/opt/local/bin/clang++-mp-11' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++ -arch i386' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch i386' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -isystem/opt/local/include' 'CFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -arch i386'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -54,7 +54,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "2.7.0"
+  CONFIG["ruby_version"] = "3.0.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "i386-darwin10.0"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -94,7 +94,7 @@ module RbConfig
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["EXTLDFLAGS"] = ""
-  CONFIG["strict_warnflags"] = ""
+  CONFIG["strict_warnflags"] = "-std=gnu99"
   CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdivision-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wmissing-noreturn -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wextra-tokens"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3"
@@ -110,11 +110,10 @@ module RbConfig
   CONFIG["PREP"] = "miniruby$(EXEEXT)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
-  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby2.7"
+  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby3.0"
   CONFIG["setup"] = "Setup"
   CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
-  CONFIG["STRIP"] = "strip -A -n"
   CONFIG["SOEXT"] = "dylib"
   CONFIG["TRY_LINK"] = ""
   CONFIG["PRELOADENV"] = "DYLD_INSERT_LIBRARIES"
@@ -134,7 +133,8 @@ module RbConfig
   CONFIG["ARCH_FLAG"] = " -arch i386"
   CONFIG["DLDFLAGS"] = "-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch i386 -Wl,-multiply_defined,suppress -Wl,-undefined,dynamic_lookup -L/opt/local/lib"
   CONFIG["ALLOCA"] = ""
-  CONFIG["MATHN"] = "yes"
+  CONFIG["EGREP"] = "/usr/bin/grep -E"
+  CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["dsymutil"] = "dsymutil"
   CONFIG["codesign"] = "codesign"
   CONFIG["POSTLINK"] = "dsymutil $@; { test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@; }"
@@ -155,37 +155,36 @@ module RbConfig
   CONFIG["INSTALL_PROGRAM"] = "$(INSTALL)"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
-  CONFIG["NM"] = "nm"
   CONFIG["DLLWRAP"] = ""
   CONFIG["WINDRES"] = ""
-  CONFIG["OBJCOPY"] = ":"
-  CONFIG["OBJDUMP"] = ""
   CONFIG["ASFLAGS"] = ""
-  CONFIG["AS"] = "as"
-  CONFIG["ARFLAGS"] = "-no_warning_for_no_symbols -o "
-  CONFIG["AR"] = "libtool -static"
-  CONFIG["RANLIB"] = ":"
+  CONFIG["ARFLAGS"] = "rcu "
   CONFIG["try_header"] = ""
   CONFIG["CC_VERSION_MESSAGE"] = "clang version 11.1.0\nTarget: i386-apple-darwin10.8.0\nThread model: posix\nInstalledDir: /opt/local/libexec/llvm-11/bin"
   CONFIG["CC_VERSION"] = "$(CC) --version"
-  CONFIG["MJIT_CC"] = "/opt/local/bin/clang-mp-11"
+  CONFIG["MJIT_CC"] = "/opt/local/bin/clang-mp-11 -fdeclspec"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
   CONFIG["OUTFLAG"] = "-o "
   CONFIG["CPPOUTFILE"] = "-o conftest.i"
   CONFIG["GNU_LD"] = "no"
-  CONFIG["LD"] = "ld"
   CONFIG["GCC"] = "yes"
-  CONFIG["EGREP"] = "/usr/bin/grep -E"
-  CONFIG["GREP"] = "/usr/bin/grep"
-  CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++"
-  CONFIG["CXX"] = "/opt/local/bin/clang++-mp-11"
-  CONFIG["CPP"] = "$(CC) -E"
+  CONFIG["CPP"] = "/opt/local/bin/clang-mp-11 -E"
+  CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -fno-common"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-I/opt/local/libexec/openssl11/include -isystem/opt/local/include -I/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -fstack-protector-strong -L/opt/local/libexec/llvm-11/lib/clang/11.1.0/lib -L/opt/local/lib"
-  CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -std=c99 -fno-common"
-  CONFIG["CC"] = "/opt/local/bin/clang-mp-11"
+  CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++"
+  CONFIG["STRIP"] = "strip -S -x"
+  CONFIG["RANLIB"] = "/opt/local/bin/ranlib"
+  CONFIG["OBJDUMP"] = ""
+  CONFIG["OBJCOPY"] = ":"
+  CONFIG["NM"] = "nm"
+  CONFIG["LD"] = "/opt/local/bin/clang-mp-11"
+  CONFIG["CXX"] = "/opt/local/bin/clang++-mp-11 -fdeclspec"
+  CONFIG["AS"] = "as"
+  CONFIG["AR"] = "/opt/local/bin/ar"
+  CONFIG["CC"] = "/opt/local/bin/clang-mp-11 -fdeclspec"
   CONFIG["target_os"] = "darwin10.0"
   CONFIG["target_vendor"] = "apple"
   CONFIG["target_cpu"] = "i386"
@@ -194,13 +193,13 @@ module RbConfig
   CONFIG["host_vendor"] = "apple"
   CONFIG["host_cpu"] = "i386"
   CONFIG["host"] = "i386-apple-darwin10.0"
-  CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
-  CONFIG["RUBYW_BASE_NAME"] = "rubyw"
-  CONFIG["RUBY_BASE_NAME"] = "ruby"
   CONFIG["build_os"] = "darwin10.8.0"
   CONFIG["build_vendor"] = "apple"
   CONFIG["build_cpu"] = "i386"
   CONFIG["build"] = "i386-apple-darwin10.8.0"
+  CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
+  CONFIG["RUBYW_BASE_NAME"] = "rubyw"
+  CONFIG["RUBY_BASE_NAME"] = "ruby"
   CONFIG["RUBY_PROGRAM_VERSION"] = "$(MAJOR).$(MINOR).$(TEENY)"
   CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
   CONFIG["HAVE_GIT"] = "no"
@@ -236,7 +235,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&2.7&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&3.0&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
@@ -261,9 +260,9 @@ module RbConfig
   #   require 'rbconfig'
   #
   #   print <<-END_OF_MAKEFILE
-  #   prefix = #{Config::MAKEFILE_CONFIG['prefix']}
-  #   exec_prefix = #{Config::MAKEFILE_CONFIG['exec_prefix']}
-  #   bindir = #{Config::MAKEFILE_CONFIG['bindir']}
+  #   prefix = #{RbConfig::MAKEFILE_CONFIG['prefix']}
+  #   exec_prefix = #{RbConfig::MAKEFILE_CONFIG['exec_prefix']}
+  #   bindir = #{RbConfig::MAKEFILE_CONFIG['bindir']}
   #   END_OF_MAKEFILE
   #
   #   => prefix = /usr/local
@@ -273,7 +272,7 @@ module RbConfig
   # RbConfig.expand is used for resolving references like above in rbconfig.
   #
   #   require 'rbconfig'
-  #   p Config.expand(Config::MAKEFILE_CONFIG["bindir"])
+  #   p RbConfig.expand(RbConfig::MAKEFILE_CONFIG["bindir"])
   #   # => "/usr/local/bin"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
@@ -311,8 +310,8 @@ module RbConfig
   # :nodoc:
   # call-seq:
   #
-  #   RbConfig.fire_update!(key, val)               -> string
-  #   RbConfig.fire_update!(key, val, mkconf, conf) -> string
+  #   RbConfig.fire_update!(key, val)               -> array
+  #   RbConfig.fire_update!(key, val, mkconf, conf) -> array
   #
   # updates +key+ in +mkconf+ with +val+, and all values depending on
   # the +key+ in +mkconf+.
